#ClipboardBrowser,#item,#item_child{
    ;${font}
    ;color: ${fg}
    ;background: ${bg}
}

#ClipboardBrowser::item:alternate:!hover:!selected{
    ;color: ${alt_fg}
    ;background: ${alt_bg}
}

#ClipboardBrowser::item:selected
,#item[CopyQ_selected="true"]
,#item[CopyQ_selected="true"] #item_child
{
    ;color: ${sel_fg}
    ;background: ${sel_bg}
}

#item #item_child
,#item[CopyQ_selected="true"] #item_child
{
    ;background: transparent
}

${hsv_saturation_factor = 0.5}
    #ClipboardBrowser::item:selected:!active
    {
        ;background:${sel_bg}
        ;${sel_item_css}
    }
${hsv_saturation_factor = 2}
${hsv_value_factor = 0.9}
    #ClipboardBrowser::item:hover:selected
    {
        ;background:${sel_bg}
        ;${hover_item_css}
    }
    #ClipboardBrowser::item:hover:!selected
    {
        ;background:${bg}
        ;${hover_item_css}
    }
${hsv_saturation_factor = 1}
${hsv_value_factor = 1}

/* Omit showing current item outline. */
#ClipboardBrowser::focus{outline:0}

#ClipboardBrowser::item:focus{ ${cur_item_css} }

/* Allow user to change CSS. */
#ClipboardBrowser{ ${item_css} }
#ClipboardBrowser::item:alternate:!hover:!selected{ ${alt_item_css} }
#ClipboardBrowser::item:selected{ ${sel_item_css} }

#editor_status_bar * {
    ;background: ${edit_bg}
    ;color: ${edit_fg}
    ;border: none
}

${css:tooltip}
